# sebaubuntu_libs

[![PyPI version](https://img.shields.io/pypi/v/sebaubuntu_libs)](https://pypi.org/project/sebaubuntu_libs/)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/8c14dd62f48043fdadbc5a31361310f5)](https://app.codacy.com/gh/sebaubuntu-python/sebaubuntu_libs/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade)
[![Documentation Status](https://readthedocs.org/projects/sebaubuntu_libs/badge/?version=latest)](https://sebaubuntu_libs.readthedocs.io/en/latest/?badge=latest)

A collection of code shared between my projects

## Installation

```sh
pip3 install sebaubuntu_libs
```

## Documentation

Complete documentation at [Read the Docs](https://sebaubuntu-libs.readthedocs.io)

# License

```
#
# Copyright (C) 2022 Sebastiano Barezzi
#
# SPDX-License-Identifier: Apache-2.0
#
```
